@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::ResultSet;
 # ABSTRACT: A Result Set
-$MetaCPAN::Client::ResultSet::VERSION = '2.021000';
+$MetaCPAN::Client::ResultSet::VERSION = '2.022000';
 use Moo;
 use Carp;
 
@@ -15,7 +15,7 @@ has type => (
             grep { $_ eq $_[0] } qw<author distribution favorite
                                    file module rating release mirror package>;
     },
-    required => 1,
+    lazy => 1,
 );
 
 # in case we're returning from a scrolled search
@@ -45,6 +45,12 @@ has total => (
     },
 );
 
+has 'class' => (
+    is      => 'ro',
+    lazy    => 1,
+    builder => '_build_class',
+);
+
 sub BUILDARGS {
     my ( $class, %args ) = @_;
 
@@ -54,8 +60,18 @@ sub BUILDARGS {
     exists $args{scroller} and exists $args{items}
         and croak 'ResultSet must get either scroller or items, not both';
 
+    exists $args{type} or exists $args{class}
+        or croak 'Must pass either type or target class to ResultSet';
+
+    exists $args{type} and exists $args{class}
+        and croak 'Must pass either type or target class to ResultSet, not both';
+
     return \%args;
 }
+sub BUILD {
+    my ( $self ) = @_;
+    $self->class; # vifify and validate
+}
 
 sub next {
     my $self   = shift;
@@ -64,8 +80,7 @@ sub next {
 
     defined $result or return;
 
-    my $class = 'MetaCPAN::Client::' . ucfirst $self->type;
-    return $class->new_from_request( $result->{'_source'} || $result->{'fields'} || $result );
+    return $self->class->new_from_request( $result->{'_source'} || $result->{'fields'} || $result );
 }
 
 sub aggregations {
@@ -74,6 +89,10 @@ sub aggregations {
     return $self->has_scroller ? $self->scroller->aggregations : {};
 }
 
+sub _build_class {
+    my $self = shift;
+    return 'MetaCPAN::Client::' . ucfirst $self->type;
+}
 
 1;
 
@@ -89,7 +108,7 @@ MetaCPAN::Client::ResultSet - A Result Set
 
 =head1 VERSION
 
-version 2.021000
+version 2.022000
 
 =head1 DESCRIPTION
 
@@ -149,6 +168,10 @@ Predicate for ES scroller presence.
 
 Double checks construction of objects. You should never run this yourself.
 
+=head2 BUILD
+
+Validates the object. You should never run this yourself.
+
 =head1 AUTHORS
 
 =over 4
